@@ -235,7 +235,7 @@ enum Operations {
     Upper,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 struct Args {
     arg_column:          SelectColumns,
     cmd_operations:      bool,
