@@ -1,11 +1,4 @@
-use std::cmp;
-
-use crate::config::{Config, Delimiter};
-use crate::util;
-use crate::CliResult;
-use serde::Deserialize;
-
-static USAGE: &str = "
+static USAGE: &str = r#"
 Transforms CSV data so that all records have the same length. The length is
 the length of the longest record in the data (not counting trailing empty fields,
 but at least 1). Records with smaller lengths are padded with empty fields.
@@ -19,6 +12,7 @@ This requires a single pass and can be done with stdin.
 
 Usage:
     qsv fixlengths [options] [<input>]
+    qsv fixlengths --help
 
 fixlengths options:
     -l, --length <arg>     Forcefully set the length of each record. If a
@@ -30,50 +24,54 @@ Common options:
     -o, --output <file>    Write output to <file> instead of stdout.
     -d, --delimiter <arg>  The field delimiter for reading CSV data.
                            Must be a single character. (default: ,)
-";
+"#;
+
+use std::cmp;
+
+use serde::Deserialize;
+
+use crate::{
+    config::{Config, Delimiter},
+    util, CliResult,
+};
 
 #[derive(Deserialize)]
 struct Args {
-    arg_input: Option<String>,
-    flag_length: Option<usize>,
-    flag_output: Option<String>,
+    arg_input:      Option<String>,
+    flag_length:    Option<usize>,
+    flag_output:    Option<String>,
     flag_delimiter: Option<Delimiter>,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
     let config = Config::new(&args.arg_input)
+        .checkutf8(false)
         .delimiter(args.flag_delimiter)
         .no_headers(true)
         .flexible(true);
-    let length = match args.flag_length {
-        Some(length) => {
-            if length == 0 {
-                return fail!("Length must be greater than 0.");
-            }
-            length
+    let length = if let Some(length) = args.flag_length {
+        if length == 0 {
+            return fail!("Length must be greater than 0.");
         }
-        None => {
-            if config.is_stdin() {
-                return fail!(
-                    "<stdin> cannot be used in this command. \
-                              Please specify a file path."
-                );
-            }
-            let mut maxlen = 0usize;
-            let mut rdr = config.reader()?;
-            let mut record = csv::ByteRecord::new();
-            while rdr.read_byte_record(&mut record)? {
-                let mut nonempty_count = 0;
-                for (index, field) in record.iter().enumerate() {
-                    if index == 0 || !field.is_empty() {
-                        nonempty_count = index + 1;
-                    }
+        length
+    } else {
+        if config.is_stdin() {
+            return fail!("<stdin> cannot be used in this command. Please specify a file path.");
+        }
+        let mut maxlen = 0usize;
+        let mut rdr = config.reader()?;
+        let mut record = csv::ByteRecord::new();
+        while rdr.read_byte_record(&mut record)? {
+            let mut nonempty_count = 0;
+            for (index, field) in record.iter().enumerate() {
+                if index == 0 || !field.is_empty() {
+                    nonempty_count = index + 1;
                 }
-                maxlen = cmp::max(maxlen, nonempty_count);
             }
-            maxlen
+            maxlen = cmp::max(maxlen, nonempty_count);
         }
+        maxlen
     };
 
     let mut rdr = config.reader()?;
