@@ -15,6 +15,10 @@ The following additional statistics require loading the entire file into memory:
 cardinality, mode/antimode, median, MAD, quartiles and its related measures (IQR,
 lower/upper fences & skewness).
 
+Note that an Out-Of-Memory (OOM) check heuristic will prevent processing if the file
+is larger than the available memory minus a headroom buffer of 20% (adjustable using the
+QSV_FREEMEMORY_HEADROOM_PCT environment variable).
+
 "Antimode" is the least frequently occurring non-zero value and is the opposite of mode.
 It returns "*ALL" if all the values are unique, and only returns a preview of the first
 10 antimodes.
@@ -87,6 +91,15 @@ stats options:
                               it is shortlisted for date inferencing.
                               Set to "all" to inspect ALL fields for
                               date/datetime types. Ignored if --infer-dates is false.
+
+                              Note that false positive date matches WILL most likely occur
+                              when using "all" as unix epoch timestamps are just numbers.
+                              Be sure to only use "all" if you know the columns you're
+                              inspecting are dates, boolean or string fields.
+                              
+                              To avoid false positives, preprocess the file first 
+                              with `apply datefmt` to convert unix epoch timestamp columns
+                              to RFC3339 format.
                               [default: date,time,due,open,close,created]
     --prefer-dmy              Parse dates in dmy format. Otherwise, use mdy format.
                               Ignored if --infer-dates is false.
@@ -106,21 +119,23 @@ Common options:
                            Must be a single character. (default: ,)
 "#;
 
-// DEVELOPER NOTE: stats is heavily optimized and makes extensive use of "unsafe" calls.
-// It is a central command, that is used by `schema`/`validate`, `tojsonl` and Datapusher+.
-//
-// It was the primary reason I created the qsv fork as I needed to do GUARANTEED data type
-// inferencing & to compile smart Data Dictionaries in the most performant way possible
-// for Datapusher+ (https://github.com/dathere/datapusher-plus).
-//
-// It underpins the `schema` and `validate` commands - enabling the automatic creation of
-// a JSONschema based on a CSV's summary statistics; and use the generated JSONschema to
-// quickly validate complex CSVs (NYC's 311 data) at almost 300,000 records/sec.
-//
-// These "unsafe" calls primarily skip repetitive UTF-8 validation and unneeded bounds checking.
-//
-// To safeguard against undefined behavior, `stats` is the most extensively tested command,
-// with ~470 tests.
+/*
+DEVELOPER NOTE: stats is heavily optimized and makes extensive use of "unsafe" calls.
+It is a central command, that is used by `schema`/`validate`, `tojsonl` and Datapusher+.
+
+It was the primary reason I created the qsv fork as I needed to do GUARANTEED data type
+inferencing & to compile smart Data Dictionaries in the most performant way possible
+for Datapusher+ (https://github.com/dathere/datapusher-plus).
+
+It underpins the `schema` and `validate` commands - enabling the automatic creation of
+a JSONschema based on a CSV's summary statistics; and use the generated JSONschema to
+quickly validate complex CSVs (NYC's 311 data) at almost 300,000 records/sec.
+
+These "unsafe" calls primarily skip repetitive UTF-8 validation and unneeded bounds checking.
+
+To safeguard against undefined behavior, `stats` is the most extensively tested command,
+with ~470 tests.
+*/
 
 use std::{
     borrow::ToOwned,
@@ -193,6 +208,20 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut wtr = Config::new(&args.flag_output).writer()?;
     let fconfig = args.rconfig();
     let record_count = RECORD_COUNT.get_or_init(|| util::count_rows(&fconfig).unwrap());
+
+    if let Some(path) = fconfig.path.clone() {
+        // we're loading the entire file into memory, we need to check avail mem
+        if args.flag_everything
+            || args.flag_mode
+            || args.flag_cardinality
+            || args.flag_median
+            || args.flag_quartiles
+            || args.flag_mad
+        {
+            util::mem_file_check(&path)?;
+        }
+    }
+
     log::info!("scanning {record_count} records...");
     let (headers, stats) = match fconfig.indexed()? {
         None => args.sequential_stats(&args.flag_dates_whitelist),
@@ -992,7 +1021,7 @@ impl FieldType {
         sample: &[u8],
         current_type: FieldType,
     ) -> (FieldType, Option<i64>) {
-        if sample.is_empty() {
+        if sample.len() == 0 {
             return (TNull, None);
         }
         // no need to do type checking if current_type is already a String
@@ -1102,7 +1131,7 @@ struct TypedSum {
 impl TypedSum {
     #[inline]
     fn add(&mut self, typ: FieldType, sample: &[u8]) {
-        if sample.is_empty() {
+        if sample.len() == 0 {
             return;
         }
         #[allow(clippy::cast_precision_loss)]
@@ -1181,7 +1210,7 @@ impl TypedMinMax {
     #[inline]
     fn add(&mut self, typ: FieldType, sample: &[u8]) {
         self.str_len.add(sample.len());
-        if sample.is_empty() {
+        if sample.len() == 0 {
             return;
         }
         self.strings.add(sample.to_vec());
