@@ -1,7 +1,7 @@
 #[cfg(any(feature = "full", feature = "lite"))]
 use std::borrow::Cow;
 use std::{
-    env, fs, io,
+    env, fs,
     path::{Path, PathBuf},
     str,
 };
@@ -348,9 +348,16 @@ pub fn file_metadata(md: &fs::Metadata) -> (u64, u64) {
 }
 
 pub fn mem_file_check(path: &Path) -> Result<(), String> {
+    use indicatif::HumanBytes;
+
+    // if the file doesn't exist, we don't need to check memory
+    // as file existence is checked before this function is called
+    // and if we do get here with a non-existent file, that means
+    // we're using stdin, so this check doesn't apply
     if !path.exists() {
         return Ok(());
     }
+
     let avail_mem = {
         let mut sys = System::new_all();
         sys.refresh_memory();
@@ -362,23 +369,28 @@ pub fn mem_file_check(path: &Path) -> Result<(), String> {
         .unwrap_or(DEFAULT_FREEMEMORY_HEADROOM_PCT);
 
     // for safety, we don't want to go below 10% memory headroom
-    if mem_pct < 10 {
-        mem_pct = 10;
-    }
+    // nor above 90% memory headroom as its too memory-restrictive
+    mem_pct = mem_pct.clamp(10, 90);
 
     #[allow(clippy::cast_precision_loss)]
     let max_avail_mem = (avail_mem as f32 * ((100 - mem_pct) as f32 / 100.0_f32)) as u64;
 
-    let file_metadata = fs::metadata(path).map_err(|e| format!("Failed to get metadata: {e}"))?;
+    let file_metadata = fs::metadata(path).map_err(|e| format!("Failed to get file size: {e}"))?;
     let fsize = file_metadata.len();
-    log::info!(
-        "qsv running in non-streaming mode. Available memory: {avail_mem} bytes. Max Available \
-         memory: {max_avail_mem} bytes. QSV_FREEMEMORY_HEADROOM_PCT: {mem_pct} percent. File \
-         size: {fsize} bytes."
+    let detail_msg = format!(
+        "qsv running in non-streaming mode. Available memory: {avail_mem}. Max Available memory: \
+         {max_avail_mem}. QSV_FREEMEMORY_HEADROOM_PCT: {mem_pct} percent. File size: {fsize}.",
+        avail_mem = HumanBytes(avail_mem),
+        max_avail_mem = HumanBytes(max_avail_mem),
+        mem_pct = mem_pct,
+        fsize = HumanBytes(fsize)
     );
     if fsize > max_avail_mem {
-        return fail!("Not enough memory to process the file.");
+        return fail!(format!(
+            "Not enough memory to process the file. {detail_msg}"
+        ));
     }
+    log::info!("{detail_msg}");
 
     Ok(())
 }
@@ -452,7 +464,7 @@ pub fn range(start: Idx, end: Idx, len: Idx, index: Idx) -> Result<(usize, usize
 /// Create a directory recursively, avoiding the race conditions fixed by
 /// https://github.com/rust-lang/rust/pull/39799.
 #[cfg(any(feature = "full", feature = "lite"))]
-fn create_dir_all_threadsafe(path: &Path) -> io::Result<()> {
+fn create_dir_all_threadsafe(path: &Path) -> std::io::Result<()> {
     use std::thread;
 
     // Try 20 times. This shouldn't theoretically need to be any larger
@@ -461,7 +473,7 @@ fn create_dir_all_threadsafe(path: &Path) -> io::Result<()> {
         match fs::create_dir_all(path) {
             // This happens if a directory in `path` doesn't exist when we
             // test for it, and another thread creates it before we can.
-            Err(ref err) if err.kind() == io::ErrorKind::AlreadyExists => {}
+            Err(ref err) if err.kind() == std::io::ErrorKind::AlreadyExists => {}
             other => return other,
         }
         // We probably don't need to sleep at all, because the intermediate
@@ -498,7 +510,7 @@ impl FilenameTemplate {
         &self,
         path: P,
         unique_value: &str,
-    ) -> io::Result<csv::Writer<Box<dyn io::Write + 'static>>>
+    ) -> std::io::Result<csv::Writer<Box<dyn std::io::Write + 'static>>>
     where
         P: AsRef<Path>,
     {
